==> HorsePower-1.12-2.5.1.43-sources.jar: se/gory_moon/horsepower/recipes/ChoppingRecipe.java <==
package se.gory_moon.horsepower.recipes;

import net.minecraft.block.Block;
import net.minecraft.init.Blocks;
import net.minecraft.inventory.InventoryCrafting;
import net.minecraft.item.ItemStack;
import net.minecraft.util.ResourceLocation;
import net.minecraftforge.oredict.OreDictionary;
import net.minecraftforge.oredict.ShapedOreRecipe;
import se.gory_moon.horsepower.Configs;
import se.gory_moon.horsepower.blocks.BlockHPChoppingBase;

import javax.annotation.Nonnull;
import java.util.List;

import static se.gory_moon.horsepower.blocks.BlockChopper.createItemStack;

public class ChoppingRecipe extends ShapedOreRecipe {

    public final List<ItemStack> outputBlocks;

    public ChoppingRecipe(ResourceLocation location, List<ItemStack> variantItems, BlockHPChoppingBase result, Object... recipe) {
        super(location, result, recipe);
        this.outputBlocks = variantItems;
    }

    @Nonnull
    @Override
    public ItemStack func_77572_b(@Nonnull InventoryCrafting craftMatrix) {
        for(int i = 0; i < craftMatrix.func_70302_i_(); i++) {
            for (ItemStack ore: outputBlocks) {
                ItemStack stack = craftMatrix.func_70301_a(i);
                if (OreDictionary.itemMatches(ore, stack, false) && Block.func_149634_a(stack.func_77973_b()) != Blocks.field_150350_a) {
                    BlockHPChoppingBase block = (BlockHPChoppingBase) Block.func_149634_a(getSimpleRecipeOutput().func_77973_b());
                    if (!Configs.general.useDynamicCrafting) {
                        if ("minecraft".equals(ore.func_77973_b().getRegistryName().func_110624_b()))
                            return createItemStack(block, Block.func_149634_a(stack.func_77973_b()), stack.func_77952_i());
                        else
                            return createItemStack(block, Blocks.field_150364_r, 0);
                    }
                    return createItemStack(block, Block.func_149634_a(stack.func_77973_b()), stack.func_77952_i());
                }
            }
        }
        return super.func_77572_b(craftMatrix);
    }

    @Nonnull
    @Override
    public ItemStack func_77571_b() {
        if (!outputBlocks.isEmpty() && !output.func_190926_b()) {
            ItemStack stack = outputBlocks.get(0);
            BlockHPChoppingBase block = (BlockHPChoppingBase) Block.func_149634_a(output.func_77973_b());
            int meta = stack.func_77960_j();
            if (meta == OreDictionary.WILDCARD_VALUE)
                meta = 0;
            return createItemStack(block, Block.func_149634_a(stack.func_77973_b()), meta);

        }
        return super.func_77571_b();
    }

    public ItemStack getSimpleRecipeOutput() {
        return output;
    }
}

==> HorsePower-1.12-2.5.2.44-sources.jar: se/gory_moon/horsepower/recipes/ChoppingRecipe.java <==
package se.gory_moon.horsepower.recipes;

import net.minecraft.block.Block;
import net.minecraft.init.Blocks;
import net.minecraft.inventory.InventoryCrafting;
import net.minecraft.item.ItemStack;
import net.minecraft.util.ResourceLocation;
import net.minecraftforge.oredict.OreDictionary;
import net.minecraftforge.oredict.ShapedOreRecipe;
import se.gory_moon.horsepower.Configs;
import se.gory_moon.horsepower.blocks.BlockHPChoppingBase;

import javax.annotation.Nonnull;
import java.util.List;

import static se.gory_moon.horsepower.blocks.BlockChopper.createItemStack;

public class ChoppingRecipe extends ShapedOreRecipe {

    public final List<ItemStack> outputBlocks;

    public ChoppingRecipe(ResourceLocation location, List<ItemStack> variantItems, ItemStack result, Object... recipe) {
        super(location, result, recipe);
        this.outputBlocks = variantItems;
    }

    @Nonnull
    @Override
    public ItemStack func_77572_b(@Nonnull InventoryCrafting craftMatrix) {
        for(int i = 0; i < craftMatrix.func_70302_i_(); i++) {
            for (ItemStack ore: outputBlocks) {
                ItemStack stack = craftMatrix.func_70301_a(i);
                if (OreDictionary.itemMatches(ore, stack, false) && Block.func_149634_a(stack.func_77973_b()) != Blocks.field_150350_a) {
                    BlockHPChoppingBase block = (BlockHPChoppingBase) Block.func_149634_a(getSimpleRecipeOutput().func_77973_b());
                    if (!Configs.general.useDynamicCrafting) {
                        if ("minecraft".equals(ore.func_77973_b().getRegistryName().func_110624_b()))
                            return createItemStack(block, Block.func_149634_a(stack.func_77973_b()), stack.func_77952_i());
                        else
                            return createItemStack(block, Blocks.field_150364_r, 0);
                    }
                    return createItemStack(block, Block.func_149634_a(stack.func_77973_b()), stack.func_77952_i());
                }
            }
        }
        return super.func_77572_b(craftMatrix);
    }

    @Nonnull
    @Override
    public ItemStack func_77571_b() {
        if (!outputBlocks.isEmpty() && !output.func_190926_b()) {
            ItemStack stack = outputBlocks.get(0);
            BlockHPChoppingBase block = (BlockHPChoppingBase) Block.func_149634_a(output.func_77973_b());
            int meta = stack.func_77960_j();
            if (meta == OreDictionary.WILDCARD_VALUE)
                meta = 0;
            return createItemStack(block, Block.func_149634_a(stack.func_77973_b()), meta);

        }
        return super.func_77571_b();
    }

    public ItemStack getSimpleRecipeOutput() {
        return output;
    }
}
